pub struct MockTeamsIntegrationApi {
TeamsIntegrationApi_expectations: MockTeamsIntegrationApi_TeamsIntegrationApi,
}Fields
TeamsIntegrationApi_expectations: MockTeamsIntegrationApi_TeamsIntegrationApiImplementations
Sourceimpl MockTeamsIntegrationApi
impl MockTeamsIntegrationApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockTeamsIntegrationApi
impl MockTeamsIntegrationApi
Sourcepub fn expect_create(&mut self) -> &mut Expectation
pub fn expect_create(&mut self) -> &mut Expectation
Create an Expectation for mocking the create method
Sourcepub fn expect_incoming_post(&mut self) -> &mut Expectation
pub fn expect_incoming_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the incoming_post method
Sourcepub fn expect_redirect(&mut self) -> &mut Expectation
pub fn expect_redirect(&mut self) -> &mut Expectation
Create an Expectation for mocking the redirect method